@@ -1,12 +1,11 @@
 """initialize ixdat, giving top-level access to a few of the important structures
 """
-__version__ = "0.1.9"
+__version__ = "0.2.0"
 __title__ = "ixdat"
 __description__ = "The in-situ experimental data tool"
-__url__ = "https://github.com/ixdat/ixdat"
-__author__ = "Soren B. Scott, Kevin Krempl, Kenneth Nielsen"
-__email__ = "scott.soren@gmail.com"  # maybe we should get an orgianization email?
-# __copyright__ = "Copyright (c) 2020 ixdat"
+__url__ = "https://ixdat.readthedocs.io"
+__author__ = "Soren B. Scott, Kenneth Nielsen, et al"
+__email__ = "sbscott@ic.ac.uk"  # maybe we should get an organization email?
 __license__ = "MIT"
 
 from .measurements import Measurement
