@@ -3,24 +3,36 @@
 Demonstrated/tested at the bottom under `if __name__ == "__main__":`
 """
 
-from pathlib import Path
 import re
+from pathlib import Path
+
 import numpy as np
 
 from . import TECHNIQUE_CLASSES
-from ..data_series import TimeSeries, ValueSeries
-from ..exceptions import ReadError
 from .reading_tools import timestamp_string_to_tstamp
+from ..data_series import TimeSeries, ValueSeries, ConstantValue
+from ..exceptions import ReadError
 
 ECMeasurement = TECHNIQUE_CLASSES["EC"]
 delim = "\t"
 t_str = "time/s"
+timestamp_form_strings = [
+    "%m/%d/%Y %H:%M:%S",  # like 07/29/2020 10:31:03
+    "%m-%d-%Y %H:%M:%S",  # like 01-31-2020 10:32:02
+]
 regular_expressions = {
     "N_header_lines": "Nb header lines : (.+)\n",
     "timestamp_string": "Acquisition started on : (.+)\n",
     "loop": "Loop ([0-9]+) from point number ([0-9]+) to ([0-9]+)",
 }
 
+BIOLOGIC_ALIASES = {
+    "t": ["time/s"],
+    "raw_potential": ["Ewe/V", "<Ewe>/V"],
+    "raw_current": ["I/mA", "<I>/mA"],
+    "cycle": ["cycle number"],
+}
+
 
 class BiologicMPTReader:
     """A class to read .mpt files written by Biologic's EC-Lab.
@@ -72,7 +84,7 @@ class BiologicMPTReader:
         self.file_has_been_read = False
         self.measurement = None
 
-    def read(self, path_to_file, name=None, cls=None, **kwargs):
+    def read(self, path_to_file, name=None, cls=ECMeasurement, **kwargs):
         """Return an ECMeasurement with the data and metadata recorded in path_to_file
 
         This loops through the lines of the file, processing one at a time. For header
@@ -87,13 +99,19 @@ class BiologicMPTReader:
 
         Args:
             path_to_file (Path): The full abs or rel path including the ".mpt" extension
+            **kwargs (dict): Key-word arguments are passed to ECMeasurement.__init__
             name (str): The name to use if not the file name
             cls (Measurement subclass): The Measurement class to return an object of.
                 Defaults to `ECMeasurement` and should probably be a subclass thereof in
                 any case.
             **kwargs (dict): Key-word arguments are passed to cls.__init__
         """
+
         path_to_file = Path(path_to_file) if path_to_file else self.path_to_file
+
+        if issubclass(ECMeasurement, cls):
+            cls = ECMeasurement
+
         if self.file_has_been_read:
             print(
                 f"This {self.__class__.__name__} has already read {self.path_to_file}."
@@ -103,7 +121,6 @@ class BiologicMPTReader:
             return self.measurement
         self.name = name or path_to_file.name
         self.path_to_file = path_to_file
-        self.measurement_class = cls or ECMeasurement
         with open(self.path_to_file, "r", encoding="ISO-8859-1") as f:
             for line in f:
                 self.process_line(line)
@@ -116,7 +133,10 @@ class BiologicMPTReader:
                 f"This reader only works for files with a '{t_str}' column"
             )
         tseries = TimeSeries(
-            name=t_str, data=self.column_data[t_str], tstamp=self.tstamp, unit_name="s",
+            name=t_str,
+            data=self.column_data[t_str],
+            tstamp=self.tstamp,
+            unit_name="s",
         )
         data_series_list = [tseries]
         for column_name, data in self.column_data.items():
@@ -130,6 +150,21 @@ class BiologicMPTReader:
             )
             data_series_list.append(vseries)
 
+        series_names = [s.name for s in data_series_list]
+        aliases = {}
+        for name, potential_aliases in BIOLOGIC_ALIASES.items():
+            found_aliases = [pa for pa in potential_aliases if pa in series_names]
+            if found_aliases:
+                aliases[name] = found_aliases
+
+        for series_name in cls.essential_series_names:
+            if series_name not in series_names and series_name not in aliases:
+                name_0 = series_name + "=0"
+                data_series_list.append(
+                    ConstantValue(name=name_0, unit_name="", data=0, tseries=tseries)
+                )
+                aliases[series_name] = [name_0]
+
         obj_as_dict = dict(
             name=self.name,
             technique="EC",
@@ -137,10 +172,11 @@ class BiologicMPTReader:
             series_list=data_series_list,
             tstamp=self.tstamp,
             ec_technique=self.ec_technique,
+            aliases=aliases,
         )
         obj_as_dict.update(kwargs)
 
-        self.measurement = self.measurement_class.from_dict(obj_as_dict)
+        self.measurement = cls.from_dict(obj_as_dict)  # cls.from_dict(**init_kwargs)
         self.file_has_been_read = True
 
         return self.measurement
@@ -238,7 +274,7 @@ BIOLOGIC_TIMESTAMP_FORMS = (
     "%m/%d/%Y %H:%M:%S",  # like 07/29/2020 10:31:03
     "%m-%d-%Y %H:%M:%S.%f",  # (anticipated)
     "%m/%d/%Y %H:%M:%S.%f",  # like 04/27/2021 11:35:39.227 (EC-Lab v11.34)
-    "%m/%d/%Y %H.%M.%S",   # like 01/31/2022 11.19.17
+    "%m/%d/%Y %H.%M.%S",  # like 01/31/2022 11.19.17
 )
 
 # This tuple contains variable names encountered in .mpt files. The tuple can be used by
@@ -296,17 +332,13 @@ if __name__ == "__main__":
     from matplotlib import pyplot as plt
     from ixdat.measurements import Measurement
 
-    test_data_dir = (
-        Path(__file__).parent.parent.parent.parent
-        / "test_data/biologic_mpt_and_zilien_tsv"
-    )
+    test_data_dir = Path(__file__).parent.parent.parent.parent / "test_data/biologic"
 
-    path_to_test_file = (
-        test_data_dir / "2020-07-29 10_30_39 Pt_poly_cv_01_02_CVA_C01.mpt"
-    )
+    path_to_test_file = test_data_dir / "Pt_poly_cv.mpt"
 
     ec_measurement = Measurement.read(
-        reader="biologic", path_to_file=path_to_test_file,
+        reader="biologic",
+        path_to_file=path_to_test_file,
     )
 
     t, v = ec_measurement.grab_potential(tspan=[0, 100])
